/*
 * (C) 1995-2001 Clemson University and Argonne National Laboratory.
 *
 * See COPYING in top-level directory.
 */


/* This file contains PVFS library call for stat.   		*/
/* It will determine if file is UNIX or PVFS and then 	*/
/* make the proper request.										*/

#include <lib.h>
#include <meta.h>

extern int errno;
extern int pvfs_checks_disabled;

int pvfs_ostat(char* pathname, struct stat *buf)
{
	return pvfs_stat(pathname, buf);
}

int pvfs_stat(char* pathname, struct stat *buf)
{
	int i, s;
	mack ack;
	mreq request;
	struct sockaddr *saddr;
	char *fn;
	int64_t fs_ino;

	if (!pathname) {
		errno = EFAULT;
		return(-1);
	}

	if (pvfs_checks_disabled) return (unix_stat(pathname, buf));

	if ((i = pvfs_detect(pathname, &fn, &saddr, &fs_ino)) < 1) {
		if (i < 0) {
			PERROR("Error finding file");
			return(-1);
		}	
		return (unix_stat(pathname, buf));
	}

	/* Prepare request for file system  */
	request.dsize = strlen(fn);
	request.uid = getuid();
	request.gid = getgid();
	request.type = MGR_STAT;

	/* Send request to mgr */
	if ((s = send_mreq_saddr(saddr, &request, fn, &ack)) < 0) {
		PERROR("send_mreq");
		return(-1);
	}

	COPY_STAT(buf, &ack.ack.stat.meta.u_stat);
	return (0);
}
